# Dutch large-scale topo-data (BGT) to GML

In this example Dutch large-scale topo-data (BGT) to a flattened GML feature collection.

**NB this example is outdated.**
**For a production version see https://github.com/nlextract/NLExtract/tree/master/bgt/etl**
